# Release information about CSSMenu

version = "0.1a0"

description = "A wrapper for jsDOMenu"
long_description = "On early stages.\nThe jsDOMenu library is GPL." 
author = "Claudio Martinez"
email = "claudio.s.martinez@gmail.com"
# copyright = "Vintage 2006 - a good year indeed"

# if it's open source, you might want to specify these
# url = "http://yourcool.site/"
# download_url = "http://yourcool.site/download"
license = "MIT"
